[asterisk-commits] mvanbaak: trunk r175952 - in /trunk: ./ channels/ doc/ include/asterisk/

SVN commits to the Asterisk project asterisk-commits at lists.digium.com
Sun Feb 15 18:27:00 CST 2009


Author: mvanbaak
Date: Sun Feb 15 18:26:59 2009
New Revision: 175952

URL: http://svn.digium.com/svn-view/asterisk?view=rev&rev=175952
Log:
Merged revisions 175921 via svnmerge from 
https://origsvn.digium.com/svn/asterisk/branches/1.4

........
  r175921 | mvanbaak | 2009-02-16 00:37:03 +0100 (Mon, 16 Feb 2009) | 3 lines
  
  fix mis-spelling of the word registered.
  Reported by De_Mon on #asterisk-dev.
........

Modified:
    trunk/   (props changed)
    trunk/channels/chan_sip.c
    trunk/channels/chan_unistim.c
    trunk/doc/unistim.txt
    trunk/include/asterisk/manager.h

Propchange: trunk/
------------------------------------------------------------------------------
Binary property 'branch-1.4-merged' - no diff available.

Modified: trunk/channels/chan_sip.c
URL: http://svn.digium.com/svn-view/asterisk/trunk/channels/chan_sip.c?view=diff&rev=175952&r1=175951&r2=175952
==============================================================================
--- trunk/channels/chan_sip.c (original)
+++ trunk/channels/chan_sip.c Sun Feb 15 18:26:59 2009
@@ -694,7 +694,7 @@
 
 /*! \brief States for outbound registrations (with register= lines in sip.conf */
 enum sipregistrystate {
-	REG_STATE_UNREGISTERED = 0,	/*!< We are not registred 
+	REG_STATE_UNREGISTERED = 0,	/*!< We are not registered 
 		 *  \note Initial state. We should have a timeout scheduled for the initial
 		 * (or next) registration transmission, calling sip_reregister
 		 */
@@ -21967,7 +21967,7 @@
 	*/
 	if (create_addr(p, host, NULL, 1)) {
 		*cause = AST_CAUSE_UNREGISTERED;
-		ast_debug(3, "Cant create SIP call - target device not registred\n");
+		ast_debug(3, "Cant create SIP call - target device not registered\n");
 		dialog_unlink_all(p, TRUE, TRUE);
 		dialog_unref(p, "unref dialog p UNREGISTERED");
 		/* sip_destroy(p); */

Modified: trunk/channels/chan_unistim.c
URL: http://svn.digium.com/svn-view/asterisk/trunk/channels/chan_unistim.c?view=diff&rev=175952&r1=175951&r2=175952
==============================================================================
--- trunk/doc/unistim.txt (original)
+++ trunk/doc/unistim.txt Sun Feb 15 18:26:59 2009
@@ -64,7 +64,7 @@
 - This feature must only be used on a trusted network. It's very insecure : all unistim phones
   will be able to use your asterisk pbx.
 - You must add an entry called [template]. Each new phones will be based on this profile.
-- You must set a least line=>. This value will be incremented when a new phone is registred.
+- You must set a least line=>. This value will be incremented when a new phone is registered.
   device= must not be specified. By default, the phone will asks for a number. It will be added into
   the dialplan. Add extension=line for using the generated line number instead.
  Example :

Modified: trunk/include/asterisk/manager.h
URL: http://svn.digium.com/svn-view/asterisk/trunk/include/asterisk/manager.h?view=diff&rev=175952&r1=175951&r2=175952
==============================================================================
--- trunk/channels/chan_unistim.c (original)
+++ trunk/channels/chan_unistim.c Sun Feb 15 18:26:59 2009
@@ -1117,7 +1117,7 @@
 		cur = cur->next;
 	}
 	if (cur) {				      /* Session found ? */
-		if (cur->device) {	      /* This session was registred ? */
+		if (cur->device) {	      /* This session was registered ? */
 			s->state = STATE_CLEANING;
 			if (unistimdebug)
 				ast_verb(0, "close_client session %p device %p lines %p sub %p\n",
@@ -3324,7 +3324,7 @@
 			for (i = 1; i < 6; i++)
 				send_favorite(i, 0, pte, "");
 			send_text(TEXT_LINE0, TEXT_NORMAL, pte, "Sorry, this phone is not");
-			send_text(TEXT_LINE1, TEXT_NORMAL, pte, "registred in unistim.cfg");
+			send_text(TEXT_LINE1, TEXT_NORMAL, pte, "registered in unistim.cfg");
 			strcpy(tmp, "MAC = ");
 			strcat(tmp, pte->macaddr);
 			send_text(TEXT_LINE2, TEXT_NORMAL, pte, tmp);
@@ -3419,7 +3419,7 @@
 	if (memcmp(buf + SIZE_HEADER, packet_recv_pick_up, sizeof(packet_recv_pick_up)) == 0) {
 		if (unistimdebug)
 			ast_verb(0, "Handset off hook\n");
-		if (!pte->device)	       /* We are not yet registred (asking for a TN in AUTOPROVISIONING_TN) */
+		if (!pte->device)	       /* We are not yet registered (asking for a TN in AUTOPROVISIONING_TN) */
 			return;
 		pte->device->receiver_state = STATE_OFFHOOK;
 		if (pte->device->output == OUTPUT_HEADPHONE)

Modified: trunk/doc/unistim.txt
URL: http://svn.digium.com/svn-view/asterisk/trunk/doc/unistim.txt?view=diff&rev=175952&r1=175951&r2=175952
==============================================================================
--- trunk/include/asterisk/manager.h (original)
+++ trunk/include/asterisk/manager.h Sun Feb 15 18:26:59 2009
@@ -147,8 +147,8 @@
 	const char *synopsis,
 	const char *description);
 
-/*! \brief Unregister a registred manager command 
-	\param action Name of registred Action:
+/*! \brief Unregister a registered manager command 
+	\param action Name of registered Action:
 */
 int ast_manager_unregister( char *action );
 




More information about the asterisk-commits mailing list